summaryrefslogtreecommitdiffstats
path: root/src/jogl/classes/com/jogamp/opengl/GLArrayData.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/jogl/classes/com/jogamp/opengl/GLArrayData.java')
-rw-r--r--src/jogl/classes/com/jogamp/opengl/GLArrayData.java18
1 files changed, 13 insertions, 5 deletions
diff --git a/src/jogl/classes/com/jogamp/opengl/GLArrayData.java b/src/jogl/classes/com/jogamp/opengl/GLArrayData.java
index ea2dfb0f3..972b10d4e 100644
--- a/src/jogl/classes/com/jogamp/opengl/GLArrayData.java
+++ b/src/jogl/classes/com/jogamp/opengl/GLArrayData.java
@@ -28,6 +28,7 @@
package com.jogamp.opengl;
+import java.io.PrintStream;
import java.nio.Buffer;
import com.jogamp.opengl.fixedfunc.GLPointerFunc;
@@ -159,26 +160,26 @@ public interface GLArrayData {
/**
* The number of components per element
*/
- public int getComponentCount();
+ public int getCompsPerElem();
/**
* The component's GL data type, ie. GL_FLOAT
*/
- public int getComponentType();
+ public int getCompType();
/**
* The component's size in bytes
*/
- public int getComponentSizeInBytes();
+ public int getBytesPerComp();
/**
* The current number of used elements.
* <p>
* On element consist out of {@link #getComponentCount()} components.
* </p>
* In case the buffer's position is 0 (sealed, flipped), it's based on it's limit instead of it's position.
*/
- public int getElementCount();
+ public int getElemCount();
/**
* The currently used size in bytes.<br>
@@ -187,6 +188,13 @@ public interface GLArrayData {
public int getSizeInBytes();
/**
+ * The current capacity in bytes.
+ */
+ public int getCapacityInBytes();
+
+ public void printStats(final PrintStream out);
+
+ /**
* True, if GL shall normalize fixed point data while converting
* them into float.
* <p>
@@ -159,26 +160,26 @@ public interface GLArrayData {
* The current number of used elements.
* <p>
- * On element consist out of {@link #getComponentCount()} components.
+ * On element consist out of {@link #getCompsPerElem()} components.
* </p>
* In case the buffer's position is 0 (sealed, flipped), it's based on it's limit instead of it's position.